# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-09-24 13:12
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('concierge_paas_plugin', '0002_user'),
    ]

    operations = [
        migrations.DeleteModel(
            name='User',
        ),
    ]
