# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-09-20 10:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Configuration',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('end_point', models.URLField()),
                ('token', models.CharField(max_length=50)),
                ('trigger', models.BooleanField(default=False)),
                ('default', models.BooleanField(default=False)),
            ],
        ),
        migrations.RunSQL([('INSERT INTO concierge_paas_plugin_configuration (trigger, end_point, token, \'default\') values (%s, %s, %s, %s)', [True, 'https://graphql.gccollab.ca/protected', 'aeb69b36cc2d332be878887971a61bf16411c3c0', True])])
    ]
